@@ -83,6 +83,7 @@ class EdgeFunction(
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
         events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -127,6 +128,7 @@ class EdgeFunction(
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        :param ephemeral_storage_size: The size of the function’s /tmp directory in MB. Default: 512 MiB
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -169,6 +171,7 @@ class EdgeFunction(
             description=description,
             environment=environment,
             environment_encryption=environment_encryption,
+            ephemeral_storage_size=ephemeral_storage_size,
             events=events,
             filesystem=filesystem,
             function_name=function_name,
@@ -400,7 +403,7 @@ class EdgeFunction(
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
         :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
         :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param label: Label for this metric when added to a Graph in a Dashboard. You can use `dynamic labels <https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/graph-dynamic-labels.html>`_ to show summary information about the entire displayed time series in the legend. For example, if you use:: [max: ${MAX}] MyMetric As the metric label, the maximum value in the visible range will be shown next to the time series name in the graph's legend. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
@@ -442,7 +445,7 @@ class EdgeFunction(
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
         :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
         :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param label: Label for this metric when added to a Graph in a Dashboard. You can use `dynamic labels <https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/graph-dynamic-labels.html>`_ to show summary information about the entire displayed time series in the legend. For example, if you use:: [max: ${MAX}] MyMetric As the metric label, the maximum value in the visible range will be shown next to the time series name in the graph's legend. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
@@ -484,7 +487,7 @@ class EdgeFunction(
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
         :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
         :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param label: Label for this metric when added to a Graph in a Dashboard. You can use `dynamic labels <https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/graph-dynamic-labels.html>`_ to show summary information about the entire displayed time series in the legend. For example, if you use:: [max: ${MAX}] MyMetric As the metric label, the maximum value in the visible range will be shown next to the time series name in the graph's legend. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
@@ -526,7 +529,7 @@ class EdgeFunction(
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
         :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
         :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param label: Label for this metric when added to a Graph in a Dashboard. You can use `dynamic labels <https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/graph-dynamic-labels.html>`_ to show summary information about the entire displayed time series in the legend. For example, if you use:: [max: ${MAX}] MyMetric As the metric label, the maximum value in the visible range will be shown next to the time series name in the graph's legend. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
@@ -568,7 +571,7 @@ class EdgeFunction(
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
         :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
         :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param label: Label for this metric when added to a Graph in a Dashboard. You can use `dynamic labels <https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/graph-dynamic-labels.html>`_ to show summary information about the entire displayed time series in the legend. For example, if you use:: [max: ${MAX}] MyMetric As the metric label, the maximum value in the visible range will be shown next to the time series name in the graph's legend. Default: - No label
         :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
         :param region: Region which this metric comes from. Default: - Deployment region.
         :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
@@ -711,6 +714,7 @@ class EdgeFunction(
         "description": "description",
         "environment": "environment",
         "environment_encryption": "environmentEncryption",
+        "ephemeral_storage_size": "ephemeralStorageSize",
         "events": "events",
         "filesystem": "filesystem",
         "function_name": "functionName",
@@ -757,6 +761,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
         events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
@@ -800,6 +805,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
+        :param ephemeral_storage_size: The size of the function’s /tmp directory in MB. Default: 512 MiB
         :param events: Event sources for this function. You can also add event sources using ``addEventSource``. Default: - No event sources.
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
@@ -891,6 +897,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["environment"] = environment
         if environment_encryption is not None:
             self._values["environment_encryption"] = environment_encryption
+        if ephemeral_storage_size is not None:
+            self._values["ephemeral_storage_size"] = ephemeral_storage_size
         if events is not None:
             self._values["events"] = events
         if filesystem is not None:
@@ -1115,6 +1123,15 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         result = self._values.get("environment_encryption")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
 
+    @builtins.property
+    def ephemeral_storage_size(self) -> typing.Optional[aws_cdk.core.Size]:
+        '''The size of the function’s /tmp directory in MB.
+
+        :default: 512 MiB
+        '''
+        result = self._values.get("ephemeral_storage_size")
+        return typing.cast(typing.Optional[aws_cdk.core.Size], result)
+
     @builtins.property
     def events(self) -> typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]]:
         '''Event sources for this function.
